AssertionType

Trait AssertionType 

trait AssertionType { }
A representation of an assertion type.

This trait is used to group the types of assertions that the MockService can do. There are currently two types that are used as type-system tags on the MockService:

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors